package controllers

import (
	"XT_New/enums"
	"XT_New/models"
	"XT_New/service"
	"XT_New/utils"
	"fmt"
	"github.com/astaxie/beego"
	"github.com/jinzhu/gorm"
	"strconv"
	"time"
)

type DoctorsApiController struct {
	BaseAuthAPIController
}

func DoctorApiRegistRouters() {
	beego.Router("/api/alldoctors", &DoctorsApiController{}, "get:GetAllDoctorAndNurse")
	beego.Router("/api/admin/users", &DoctorsApiController{}, "get:GetAllAdminUsers")
	beego.Router("/api/patient/getdryweightdata", &DoctorsApiController{}, "Get:GetDryWeightData")
	beego.Router("/api/patient/getAllDoctor", &DoctorsApiController{}, "Get:GetAllDoctor")
	beego.Router("/api/patient/updatedryweightdata", &DoctorsApiController{}, "Post:UpdatedDryWeightData")
	beego.Router("/api/patient/getalldata", &DoctorsApiController{}, "Get:GetAllData")
	beego.Router("/api/paients/getdryweightdetail", &DoctorsApiController{}, "Get:GetDryWeightDetail")
	beego.Router("/api/patients/modifydryweightdata", &DoctorsApiController{}, "Get:ModifydryWeightData")
	beego.Router("/api/patient/deletedryweight", &DoctorsApiController{}, "Delete:DeleteDryWeight")
	beego.Router("/api/schedule/advices", &DoctorsApiController{}, "Get:ScheduleAdvices")
	beego.Router("/api/schedule/getdoctoradvicecount", &DoctorsApiController{}, "Get:GetDoctorAdviceCount")
	beego.Router("/api/patient/savevasularaccess", &DoctorsApiController{}, "Get:SaveVasularAccess")
	beego.Router("/api/patient/getallvascualraccesslist", &DoctorsApiController{}, "Get:GetAllVacualAccessList")
	beego.Router("/api/patient/getvascularaccessbydetial", &DoctorsApiController{}, "Get:GetVascularAccessByDetail")
	beego.Router("/api/patient/updatevasularaccess", &DoctorsApiController{}, "Get:UpdateVasularAccess")
	beego.Router("/api/patient/deletevascularaccess", &DoctorsApiController{}, "Get:DeleteVasularAccess")
	beego.Router("/api/patient/savepasswayassessment", &DoctorsApiController{}, "Get:SavePassWayAssessment")
	beego.Router("/api/patient/getallpasswayassessment", &DoctorsApiController{}, "Get:GetAllPassWayAssessment")
	beego.Router("/api/patient/getpasswayassmentbyid", &DoctorsApiController{}, "Get:GetPasswayAssesmentById")
	beego.Router("/api/patient/updatepasswayassesment", &DoctorsApiController{}, "Get:UpdatePassWayAssesment")
	beego.Router("/api/patient/deletepasswayassessment", &DoctorsApiController{}, "Get:DeleteWayAssessment")
	beego.Router("/api/patient/getaccesslist", &DoctorsApiController{}, "Get:GetAccessList")
}

func (c *DoctorsApiController) ScheduleAdvices() {
	schedualDate := c.GetString("date")
	adviceType, _ := c.GetInt("advice_type")
	patientType, _ := c.GetInt("patient_type")
	delivery_way := c.GetString("delivery_way")
	schedule_type, _ := c.GetInt64("schedule_type")
	partition_type, _ := c.GetInt64("partition_type")
	if adviceType != 1 && adviceType != 3 && adviceType != 2 {
		adviceType = 0
	}

	if patientType != 1 && patientType != 2 {

		patientType = 0
	}

	date, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", schedualDate)
	if parseDateErr != nil {
		c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeParamWrong)
		return
	}

	adminUserInfo := c.GetAdminUserInfo()
	orgID := adminUserInfo.CurrentOrgId

	scheduals, err := service.MobileGetScheduleDoctorAdvicesOne(orgID, date.Unix(), adviceType, patientType, adminUserInfo.AdminUser.Id, delivery_way, schedule_type, partition_type)
	hisAdvices, _ := service.GetHisDoctorAdvicesOne(orgID, date.Unix(), delivery_way, schedule_type, partition_type)

	project, _ := service.GetPCHisPrescriptionProject(orgID, date.Unix(), delivery_way, patientType, partition_type)

	config, _ := service.GetHisDoctorConfig(orgID)
	project_config, _ := service.GetHisProjectConfig(orgID)

	adminUser, _ := service.GetAllAdminUsers(orgID, adminUserInfo.CurrentAppId)
	if err != nil {
		c.ErrorLog("获取排班信息失败:%v", err)
		c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
	} else {
		filtedScheduals := []*service.MScheduleDoctorAdviceVM{}
		for _, schedual := range scheduals {
			if len(schedual.DoctorAdvices) > 0 {
				filtedScheduals = append(filtedScheduals, schedual)
			}
		}
		c.ServeSuccessJSON(map[string]interface{}{
			"scheduals":      filtedScheduals,
			"adminUser":      adminUser,
			"hisAdvices":     hisAdvices,
			"config":         config,
			"project_config": project_config,
			"project":        project,
		})
	}
}

func (c *DoctorsApiController) GetAllDoctorAndNurse() {

	adminUserInfo := c.GetAdminUserInfo()
	doctors, nursers, _ := service.GetAllDoctorAndNurse(adminUserInfo.CurrentOrgId, adminUserInfo.CurrentAppId)

	c.ServeSuccessJSON(map[string]interface{}{
		"doctors": doctors,
		"nursers": nursers,
	})
	return
}
func (c *DoctorsApiController) GetAllAdminUsers() {

	adminUserInfo := c.GetAdminUserInfo()
	users, _ := service.GetAllAdminUsersTwo(adminUserInfo.CurrentOrgId)
	c.ServeSuccessJSON(map[string]interface{}{
		"users": users,
	})
	return
}

func (c *DoctorsApiController) GetDryWeightData() {
	adminUserInfo := c.GetAdminUserInfo()
	orgid := adminUserInfo.CurrentOrgId

	patientid, _ := c.GetInt64("patientid")
	fmt.Println("patientid", patientid)
	id := adminUserInfo.AdminUser.Id
	fmt.Println("id", id)
	recordDateStr := time.Now().Format("2006-01-02")
	recordDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", recordDateStr)
	fmt.Scan("parseDateErr", parseDateErr)
	nowtime := recordDate.Unix()
	fmt.Println("nowtime", nowtime)
	pre, err := service.GetDryWeightByPatientId(patientid, orgid)
	fmt.Println("错误", err)
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": pre,
	})
}

func (c *DoctorsApiController) GetAllDoctor() {
	adminUserInfo := c.GetAdminUserInfo()
	orgid := adminUserInfo.CurrentOrgId
	appid := adminUserInfo.CurrentAppId
	fmt.Println("appid", appid)
	appRole, err := service.GetAllDoctor(orgid, appid)
	fmt.Println("appRole", appRole)
	fmt.Println("错误", err)
	c.ServeSuccessJSON(map[string]interface{}{
		"appRole": appRole,
	})
}

func (c *DoctorsApiController) UpdatedDryWeightData() {
	adminUserInfo := c.GetAdminUserInfo()
	orgid := adminUserInfo.CurrentOrgId
	userid := adminUserInfo.AdminUser.Id
	fmt.Println("userid", userid)
	dry_weight, _ := c.GetFloat("dry_weight")
	fmt.Println("dry_weight", dry_weight)
	doctors, _ := c.GetInt64("doctors")
	fmt.Println("doctors", doctors)
	remarks := c.GetString("remarks")
	fmt.Println("remarks", remarks)
	patientid, _ := c.GetInt64("patient_id")
	fmt.Println("patientid", patientid)
	//透前数据
	dryweight, _ := c.GetFloat("dryweight")
	fmt.Println("dryweight", dryweight)
	var weight = dryweight - dry_weight
	weights := fmt.Sprintf("%.1f", weight)
	//weights := strconv.FormatFloat(sprintf, 'E', -1, 64)

	fmt.Println("weight", weights)
	fmt.Println("weight", weight)
	var sum string
	dryWeight, errcode := service.QueryDryWeight(orgid, patientid)
	fmt.Println("errcode", errcode)
	fmt.Println("dryWeight", dryWeight)
	if errcode == gorm.ErrRecordNotFound {
		sum = "/"
		patientDryweight := models.SgjPatientDryweight{
			DryWeight:     dry_weight,
			Creator:       doctors,
			Remakes:       remarks,
			AdjustedValue: sum,
			PatientId:     patientid,
			Ctime:         time.Now().Unix(),
			UserOrgId:     orgid,
			Status:        1,
			UserId:        userid,
		}

		err := service.CreatePatientWeight(&patientDryweight)
		fmt.Println("err", err)
		c.ServeSuccessJSON(map[string]interface{}{
			"patientDryweight": patientDryweight,
		})
		return
	}
	fmt.Println("sum", sum)
	if weight == 0 {
		sum = "/"
	}
	if weight > 0 {
		sum = weights + "(" + "下调" + ")"

	}
	if weight < 0 {
		var sums = dry_weight - dryweight
		float := fmt.Sprintf("%.1f", sums)
		//float := strconv.FormatFloat(sums, 'E', -1, 64)
		sum = float + "(" + "上调" + ")"
	}

	patientDryweight := models.SgjPatientDryweight{
		DryWeight:     dry_weight,
		Creator:       doctors,
		Remakes:       remarks,
		AdjustedValue: sum,
		PatientId:     patientid,
		Ctime:         time.Now().Unix(),
		UserOrgId:     orgid,
		Status:        1,
		UserId:        userid,
	}

	err := service.CreatePatientWeight(&patientDryweight)
	//sgjPatientDryweight, _ := service.GetLastData(orgid)
	recordDateStr := time.Now().Format("2006-01-02")
	recordDate, parseDateErr := utils.ParseTimeStringToTime("2006-01-02", recordDateStr)
	fmt.Scan("parseDateErr", parseDateErr)
	nowtime := recordDate.Unix()
	fmt.Println("nowtime", nowtime)
	//prescription := models.PredialysisEvaluation{
	//	DryWeight: dryweight,
	//}
	//errors := service.UpdateDialysisPrescription( sgjPatientDryweight.PatientId, sgjPatientDryweight.UserOrgId, sgjPatientDryweight.DryWeight, prescription)
	//fmt.Println("error",errors)
	fmt.Println("err", err)
	fmt.Println("patientdryweight", patientDryweight)
	c.ServeSuccessJSON(map[string]interface{}{
		"patientDryweight": patientDryweight,
	})
}

func (c *DoctorsApiController) GetAllData() {
	id, _ := c.GetInt64("id")
	page, _ := c.GetInt64("page")
	fmt.Println("page", page)
	limit, _ := c.GetInt64("limit")
	fmt.Println("limit", limit)

	fmt.Println("id", id)
	adminUserInfo := c.GetAdminUserInfo()
	orgid := adminUserInfo.CurrentOrgId
	dry, total, _ := service.GetAllData(orgid, id, page, limit)

	c.ServeSuccessJSON(map[string]interface{}{
		"dry":   dry,
		"total": total,
	})
}

func (c *DoctorsApiController) GetDryWeightDetail() {

	id, _ := c.GetInt64("id")
	dryweight, _ := service.GetDryWeightDetailById(id)
	c.ServeSuccessJSON(map[string]interface{}{
		"dryweight": dryweight,
	})
}

func (c *DoctorsApiController) ModifydryWeightData() {

	adjustvalue := c.GetString("adjustvalue")

	creator, _ := c.GetInt64("creator")

	dryweight, _ := c.GetInt64("dryweight")
	dry := strconv.FormatInt(dryweight, 10)
	dry_weight, _ := strconv.ParseFloat(dry, 64)
	id, _ := c.GetInt64("id")

	remark := c.GetString("remark")

	patientDryweight := models.SgjPatientDryweight{
		AdjustedValue: adjustvalue,
		Creator:       creator,
		DryWeight:     dry_weight,
		Remakes:       remark,
	}
	service.ModifyDryWeightData(&patientDryweight, id)
	c.ServeSuccessJSON(map[string]interface{}{
		"patientDryweight": patientDryweight,
	})
}

func (c *DoctorsApiController) DeleteDryWeight() {

	id, _ := c.GetInt64("id")
	service.DeleteDryWeight(id)
	returnData := make(map[string]interface{}, 0)
	returnData["msg"] = "ok"
	c.ServeSuccessJSON(returnData)
	return
}

func (c *DoctorsApiController) GetDoctorAdviceCount() {
	timeLayout := "2006-01-02"
	loc, _ := time.LoadLocation("Local")
	start_time := c.GetString("start_time")
	startTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", start_time+" 00:00:00", loc)

	end_time := c.GetString("end_time")
	endTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", end_time+" 00:00:00", loc)

	delive_way := c.GetString("delive_way")
	adminUserInfo := c.GetAdminUserInfo()
	orgId := adminUserInfo.CurrentOrgId
	list, _ := service.GetDoctorAdviceCount(startTime.Unix(), endTime.Unix(), delive_way, orgId)
	if len(list) == 0 {
		list, _ := service.GetHisDoctorAdviceCount(startTime.Unix(), endTime.Unix(), delive_way, orgId)
		c.ServeSuccessJSON(map[string]interface{}{
			"list": list,
		})
	} else {
		c.ServeSuccessJSON(map[string]interface{}{
			"list": list,
		})
	}

}

func (this *DoctorsApiController) SaveVasularAccess() {

	access_project, _ := this.GetInt64("access_project")
	blood_access_part_id := this.GetString("blood_access_part_id")
	blood_access_part_opera_id := this.GetString("blood_access_part_opera_id")
	first_start_time := this.GetString("first_start_time")
	timeLayout := "2006-01-02"
	loc, _ := time.LoadLocation("Local")
	firstStartTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", first_start_time+" 00:00:00", loc)
	inflow_pass := this.GetString("inflow_pass")
	remark := this.GetString("remark")
	start_time := this.GetString("start_time")
	startTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", start_time+" 00:00:00", loc)
	stop_reason := this.GetString("stop_reason")
	user_status, _ := this.GetInt64("user_status")
	stop_time := this.GetString("stop_time")
	stopTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", stop_time+" 00:00:00", loc)
	patient_id, _ := this.GetInt64("patient_id")
	other_vascular := this.GetString("other_vascular")
	ci_type, _ := this.GetInt64("ci_type")
	blood_cultupe, _ := this.GetInt64("blood_cultupe")
	sequelae_type, _ := this.GetInt64("sequelae_type")
	adminUserInfo := this.GetAdminUserInfo()
	orgId := adminUserInfo.CurrentOrgId
	creator := adminUserInfo.AdminUser.Id

	//查询改日期是否存在
	access := models.XtPatientVascularAccess{
		AccessProject:          access_project,
		BloodAccessPartId:      blood_access_part_id,
		BloodAccessPartOperaId: blood_access_part_opera_id,
		FirstStartTime:         firstStartTime.Unix(),
		InflowPass:             inflow_pass,
		Remark:                 remark,
		StartTime:              startTime.Unix(),
		StopReason:             stop_reason,
		UserStatus:             user_status,
		Creator:                creator,
		UserOrgId:              orgId,
		Status:                 1,
		Ctime:                  time.Now().Unix(),
		StopTime:               stopTime.Unix(),
		PatientId:              patient_id,
		OtherVascular:          other_vascular,
		CiType:                 ci_type,
		BloodCultupe:           blood_cultupe,
		SequelaeType:           sequelae_type,
	}
	err := service.SaveVascularAccess(&access)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"access": access,
		})
		return
		//_, errcode := service.GetDialysisDateByDate(startTime.Unix(), patient_id, orgId)
		//if errcode == gorm.ErrRecordNotFound {
		//	access := models.XtPatientVascularAccess{
		//		AccessProject:          access_project,
		//		BloodAccessPartId:      blood_access_part_id,
		//		BloodAccessPartOperaId: blood_access_part_opera_id,
		//		FirstStartTime:         firstStartTime.Unix(),
		//		InflowPass:             inflow_pass,
		//		Remark:                 remark,
		//		StartTime:              startTime.Unix(),
		//		StopReason:             stop_reason,
		//		UserStatus:             user_status,
		//		Creator:                creator,
		//		UserOrgId:              orgId,
		//		Status:                 1,
		//		Ctime:                  time.Now().Unix(),
		//		StopTime:               stopTime.Unix(),
		//		PatientId:              patient_id,
		//		OtherVascular:          other_vascular,
		//		CiType:                 ci_type,
		//		BloodCultupe:           blood_cultupe,
		//		SequelaeType:           sequelae_type,
		//	}
		//	err := service.SaveVascularAccess(&access)
		//	if err == nil {
		//		this.ServeSuccessJSON(map[string]interface{}{
		//			"access": access,
		//		})
		//		return
		//	}
		//} else if errcode == nil {
		//	this.ServeFailJSONWithSGJErrorCode(enums.ErrorDialysisOrderRepeatBed)
		//	return
	}

}

func (this *DoctorsApiController) GetAllVacualAccessList() {

	limit, _ := this.GetInt64("limit")
	page, _ := this.GetInt64("page")
	patient_id, _ := this.GetInt64("patient_id")
	orgId := this.GetAdminUserInfo().CurrentOrgId
	appId := this.GetAdminUserInfo().CurrentAppId
	list, total, err := service.GetAllVacualAccessList(orgId, limit, page, patient_id)
	doctor, err := service.GetAllDoctor(orgId, appId)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"list":   list,
			"total":  total,
			"doctor": doctor,
		})
		return
	}
}

func (this *DoctorsApiController) GetVascularAccessByDetail() {

	id, _ := this.GetInt64("id")

	accessDetail, err := service.GetVasularAccessByDetail(id)
	orgId := this.GetAdminUserInfo().CurrentOrgId
	appId := this.GetAdminUserInfo().CurrentAppId
	doctor, err := service.GetAllDoctor(orgId, appId)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"accessDetail": accessDetail,
			"doctor":       doctor,
		})
		return
	}
}

func (this *DoctorsApiController) UpdateVasularAccess() {
	id, _ := this.GetInt64("id")
	access_project, _ := this.GetInt64("access_project")
	blood_access_part_id := this.GetString("blood_access_part_id")
	blood_access_part_opera_id := this.GetString("blood_access_part_opera_id")
	first_start_time := this.GetString("first_start_time")
	timeLayout := "2006-01-02"
	loc, _ := time.LoadLocation("Local")
	firstStartTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", first_start_time+" 00:00:00", loc)
	inflow_pass := this.GetString("inflow_pass")
	remark := this.GetString("remark")
	start_time := this.GetString("start_time")
	startTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", start_time+" 00:00:00", loc)
	stop_reason := this.GetString("stop_reason")
	user_status, _ := this.GetInt64("user_status")
	stop_time := this.GetString("stop_time")
	stopTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", stop_time+" 00:00:00", loc)
	adminUserInfo := this.GetAdminUserInfo()
	orgId := adminUserInfo.CurrentOrgId
	creator := adminUserInfo.AdminUser.Id
	patientId, _ := this.GetInt64("patient_id")
	other_vascular := this.GetString("other_vascular")
	ci_type, _ := this.GetInt64("ci_type")
	blood_cultupe, _ := this.GetInt64("blood_cultupe")
	sequelae_type, _ := this.GetInt64("sequelae_type")
	access := models.XtPatientVascularAccess{
		AccessProject:          access_project,
		BloodAccessPartId:      blood_access_part_id,
		BloodAccessPartOperaId: blood_access_part_opera_id,
		FirstStartTime:         firstStartTime.Unix(),
		InflowPass:             inflow_pass,
		Remark:                 remark,
		StartTime:              startTime.Unix(),
		StopReason:             stop_reason,
		UserStatus:             user_status,
		Modify:                 creator,
		UserOrgId:              orgId,
		Status:                 1,
		StopTime:               stopTime.Unix(),
		OtherVascular:          other_vascular,
		CiType:                 ci_type,
		BloodCultupe:           blood_cultupe,
		SequelaeType:           sequelae_type,
		PatientId:              patientId,
	}

	err := service.UpdateVascularAccess(&access, id)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"access": access,
		})
		return
	}
	//_, errcode := service.GetDialysisDateByDateOne(startTime.Unix(), patientId, orgId, id)
	//if errcode == gorm.ErrRecordNotFound {
	//	err := service.UpdateVascularAccess(&access, id)
	//	if err == nil {
	//		this.ServeSuccessJSON(map[string]interface{}{
	//			"access": access,
	//		})
	//		return
	//	}
	//} else if errcode == nil {
	//	this.ServeFailJSONWithSGJErrorCode(enums.ErrorDialysisOrderRepeatBed)
	//	return
	//}

}

func (this *DoctorsApiController) DeleteVasularAccess() {
	id, _ := this.GetInt64("id")
	err := service.DeleteVasularAccess(id)
	fmt.Println(err)
	returnData := make(map[string]interface{}, 0)
	returnData["msg"] = "ok"
	this.ServeSuccessJSON(returnData)
	return
}

func (this *DoctorsApiController) SavePassWayAssessment() {

	blood_dealwidth := this.GetString("blood_dealwith")
	blood_project := this.GetString("blood_project")
	blood_result := this.GetString("blood_result")
	creator, _ := this.GetInt64("creator")
	parent_id, _ := this.GetInt64("parent_id")
	patient_id, _ := this.GetInt64("patient_id")
	start_time := this.GetString("start_time")
	timeLayout := "2006-01-02"
	loc, _ := time.LoadLocation("Local")
	startTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", start_time+" 00:00:00", loc)
	modify := this.GetAdminUserInfo().AdminUser.Id
	orgId := this.GetAdminUserInfo().CurrentOrgId
	assessment := models.XtPatientPasswayAssessment{
		StartTime:     startTime.Unix(),
		BloodDealwith: blood_dealwidth,
		BloodProject:  blood_project,
		BloodResult:   blood_result,
		Creator:       creator,
		PatientId:     patient_id,
		ParentId:      parent_id,
		Modify:        modify,
		UserOrgId:     orgId,
		Status:        1,
		Ctime:         time.Now().Unix(),
	}

	err := service.CreatePatientWayAssessment(&assessment)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"assessment": assessment,
		})
		return
	}
}

func (this *DoctorsApiController) GetAllPassWayAssessment() {

	patient_id, _ := this.GetInt64("patient_id")
	parent_id, _ := this.GetInt64("parent_id")
	page, _ := this.GetInt64("page")
	limit, _ := this.GetInt64("limit")
	adminUserInfo := this.GetAdminUserInfo()
	list, total, err := service.GetAllPassWayAssessment(parent_id, patient_id, page, limit, adminUserInfo.CurrentOrgId)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"list":  list,
			"total": total,
		})
		return
	}
}

func (this *DoctorsApiController) GetPasswayAssesmentById() {

	id, _ := this.GetInt64("id")
	assessment, err := service.GetPasswayAssesmentById(id)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"assessment": assessment,
		})
		return
	}
}

func (this *DoctorsApiController) UpdatePassWayAssesment() {
	id, _ := this.GetInt64("id")
	blood_dealwidth := this.GetString("blood_dealwith")
	blood_project := this.GetString("blood_project")
	blood_result := this.GetString("blood_result")
	creator, _ := this.GetInt64("creator")
	start_time := this.GetString("start_time")
	timeLayout := "2006-01-02"
	loc, _ := time.LoadLocation("Local")
	startTime, _ := time.ParseInLocation(timeLayout+" 15:04:05", start_time+" 00:00:00", loc)
	modify := this.GetAdminUserInfo().AdminUser.Id
	assessment := models.XtPatientPasswayAssessment{
		BloodResult:   blood_result,
		BloodDealwith: blood_dealwidth,
		BloodProject:  blood_project,
		Creator:       creator,
		StartTime:     startTime.Unix(),
		Modify:        modify,
	}
	err := service.UpdatePassWayAssesment(&assessment, id)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"assessment": assessment,
		})
		return
	}
}

func (this *DoctorsApiController) DeleteWayAssessment() {

	id, _ := this.GetInt64("id")
	err := service.DeleteWayAssessment(id)
	fmt.Println(err)
	returnData := make(map[string]interface{}, 0)
	returnData["msg"] = "ok"
	this.ServeSuccessJSON(returnData)
	return
}

func (this *DoctorsApiController) GetAccessList() {

	adminUserInfo := this.GetAdminUserInfo()
	orgId := adminUserInfo.CurrentOrgId
	//血管通路
	list, err := service.GetAccessList(orgId)
	blood_access_part_opera, err := service.GetParentAccessList(orgId, list.ID)

	//血管通路部位
	access, err := service.GetBloodAccess(orgId)
	blood_access_part, err := service.GetParentAccessList(orgId, access.ID)
	if err == nil {
		this.ServeSuccessJSON(map[string]interface{}{
			"blood_access_part_opera": blood_access_part_opera,
			"blood_access_part":       blood_access_part,
		})
		return
	}
}
